@@ -61,16 +61,23 @@ def link_type_detail_view(request: Request, **kwargs) -> Response:
 def get_link_instance_url(instance: Model, link_all_model: LinkAllModel) -> str:
     url_attr = getattr(instance, link_all_model.url_method, None)
     if url_attr is None:
-        logger.error(
-            f"Link all: the specified url method returned a None, falling back to rendering an empty url.",
-            extra={
-                'instance': instance,
-                'model': instance.link_content_type.model if instance.link_content_type else None,
-                'page': instance.page,
-                'link_all_model.model_name': link_all_model.model_name,
-                'link_all_model.url_method': link_all_model.url_method,
-            },
-        )
+        error = f"Link all: the specified url method returned a None, falling back to rendering an empty url."
+        if instance is None:
+            logger.error(error)
+        else:
+            try:
+                logger.error(
+                    error,
+                    extra={
+                        'instance': instance,
+                        'model': instance.link_content_type.model if instance.link_content_type else None,
+                        'page': instance.page,
+                        'link_all_model.model_name': link_all_model.model_name,
+                        'link_all_model.url_method': link_all_model.url_method,
+                    },
+                )
+            except:
+                logger.error("Link rendering logging failed.")
         return ''
     if type(url_attr) == str:
         return url_attr
